==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/inputs/ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.inputs

import com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property key The tag key.
 * @property value The tag value.
 */
public data class ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs(
    public val key: Output<String>? = null,
    public val `value`: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs> {
    override fun toJava():
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs =
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs.builder()
            .key(key?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs].
 */
@PulumiTagMarker
public class ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgsBuilder
internal constructor() {
    private var key: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The tag key.
     */
    @JvmName("cnpfwipcwrbkcvqs")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The tag value.
     */
    @JvmName("eypggscjlcljqjiu")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The tag key.
     */
    @JvmName("awigekffsshgegfb")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The tag value.
     */
    @JvmName("tfptucqecoagwdqb")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs =
        ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs(
            key = key,
            `value` = `value`,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/inputs/ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.inputs

import com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property key The tag key.
 * @property value The tag value.
 */
public data class ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs(
    public val key: Output<String>? = null,
    public val `value`: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs> {
    override fun toJava(): com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs =
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs.builder()
            .key(key?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs].
 */
@PulumiTagMarker
public class ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgsBuilder
internal constructor() {
    private var key: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The tag key.
     */
    @JvmName("syrsjkhmwydotnxo")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The tag value.
     */
    @JvmName("hxmbhenrolhdujtf")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The tag key.
     */
    @JvmName("ojxgqdkjxwtnqxyt")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The tag value.
     */
    @JvmName("lejhrdjlvqqsrovx")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs =
        ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValueArgs(
            key = key,
            `value` = `value`,
        )
}
